DefaultKfProduceRequest

Type Alias DefaultKfProduceRequest 

pub type DefaultKfProduceRequest = KfProduceRequest<RecordSet>;

Aliased Type

pub struct DefaultKfProduceRequest {
    pub transactional_id: Option<String>,
    pub acks: i16,
    pub timeout_ms: i32,
    pub topics: Vec<TopicProduceData<RecordSet>>,
    pub data: PhantomData<RecordSet>,
}

Fields

transactional_id: Option<String>

The transactional ID, or null if the producer is not transactional.

acks: i16

The number of acknowledgments the producer requires the leader to have received before considering a request complete. Allowed values: 0 for no acknowledgments, 1 for only the leader and -1 for the full ISR.

timeout_ms: i32

The timeout to await a response in miliseconds.

topics: Vec<TopicProduceData<RecordSet>>

Each topic to produce to.

data: PhantomData<RecordSet>